@@ -90,8 +90,7 @@ struct _Git
 	 * way of handling project (working directory) changes */
 	GitBranchListCommand *local_branch_list_command;
 	GitBranchListCommand *remote_branch_list_command;
-	GitStatusCommand *commit_status_command;
-	GitStatusCommand *not_updated_status_command;
+	GitStatusCommand *status_command;
 	GitRemoteListCommand *remote_list_command;
 	GitTagListCommand *tag_list_command;
 	GitStashListCommand *stash_list_command;
